@@ -26,7 +26,7 @@ class StandingsWidget : public QWidget
 public:
     explicit StandingsWidget(QWidget *parent);
     explicit StandingsWidget(QWidget *parent, const QList<Player *> &players);
-    ~StandingsWidget();
+    ~StandingsWidget() override;
 
     QSize sizeHint() const override;
     void update(const QList<Player *> &players);
